<template>
  <section>
    <h2>Edit Sessions</h2>
    <header
      class="row-header"
      style="padding-left: 3px; padding-right: 15px;"/>

    <grid
      ref="sessionEditGrid"
      :columns="sessionEditGridColumns"
      data-source="sessions"
      order-by="date"
      order-by-order="DESC"
      @rowSelected="EditRow( $event )" />

    <modal
      ref="editModal"
      title="Edit Session"
      large>
      <section class="row">
        <section
          v-if="selectedSession !== null"
          class="col-12">
          <section style="margin-bottom:20px;">
            <textbox
              v-model="selectedSession.school"
              label="School" />
            <textbox
              v-model="selectedSession.date"
              label="Date, format YYYY-MM-DD" />
            <label for="Size">Select New Economy Size, if desired: </label>
            <select
              id="Size"
              v-model="selectedSession.economy_size"
              style="width: 25%;"
              name="Size">
              <option
                v-for="economy in economyBases"
                :key="economy.size"
                :value="economy.size">{{ economy.size }}
              </option>
            </select><br>
            <label for="Auto Payments">Automated Payments: </label>
            <input
              v-model="selectedSession.automated_payments"
              type="checkbox"
              label="Auto Payments" ><br>
            <label for="Investment Fee">Investment Fee: </label>
            <input
              v-model="selectedSession.investmentFee"
              type="checkbox"
              label="Investment Fee" ><br>
            <label for="Service Charge">Service Charge: </label>
            <input
              v-model="selectedSession.serviceCharge"
              type="checkbox"
              label="Service Charge" ><br>
            <label for="Paycheck Deposit">Paycheck Deposit: </label>
            <input
              v-model="selectedSession.paycheckDeposit"
              type="checkbox"
              label="Paycheck Deposit" >
          </section>
        </section>
      </section>
      <section slot="footer">
        <button
          class="btn btn-secondary"
          @click="$refs.editModal.Close()">Cancel</button>
        <button
          class="btn btn-danger"
          @click="gateDeleteSession()">Delete</button>
        <button
          class="btn btn-dark"
          @click="Save()">{{ saveButtonText }}</button>
      </section>
    </modal>

  </section>


</template>



<script>
export default {
    data() {
      return {
          sessions:[],
          selectedSession:null,
          sessionEditGridColumns: [
              { "field" : "date", "name" : "Date", "span" : 2},
              { "field" : "school", "name" : "School", "span" : 5},
              { "field" : "economy_size", "name" : "Size", "span" : 1},
              { "field" : "automated_payments", "name" : "Auto Payments", "span" : 1},
              { "field" : "investmentFee", "name" : "Investment Fee", "span" : 1},
              { "field" : "serviceCharge", "name" : "Service Charge", "span" : 1},
              { "field" : "paycheckDeposit", "name" : "Paycheck Deposit", "span" : 1}
          ],
          economyBases: [],
          savingIndicator: false
      };
    },
    computed: {
      saveButtonText: function () {
        if (this.savingIndicator) {
          return "Saving...";
        } else {
          return "Save";
        }
      }
    },
    created(){
      app.api.Get("sessions/").then(response => {
        this.sessions = response;
      });
      this.getEconomyBases();
    },
    methods:{
      EditRow( row ){
        this.SetEdit(row);
        this.$refs.editModal.Open();
      },
      SetEdit( row ){
        this.selectedSession = this.sessions.filter(session => session.id == row.id)[0];
      },
      Save(){
        if( this.selectedSession !== null ){
          if(this.selectedSession.id){
            this.savingIndicator = true;
            app.api.Put("sessions/" + this.selectedSession.id, this.selectedSession).then(r => {
              app.Message("Changes saved.", "success");
              this.$refs.sessionEditGrid.Reload();
              this.savingIndicator = false;
              this.$refs.editModal.Close();
            });
          } else {
              this.$refs.sessionEditGrid.Reload();
              this.$refs.editModal.Close();
          }
        }
      },
      gateDeleteSession() {
        confirm("Are you sure you want to delete this session?")
          ? this.Delete()
          : alert("Deletion cancelled.");
      },
      Delete(){
        if(
          this.selectedSession !== null
        ){
          if(this.selectedSession.id){
            app.api.Delete("sessions/" + this.selectedSession.id).then(r => {
              this.$refs.sessionEditGrid.Reload();
              this.$refs.editModal.Close();
            });
          } else {
              this.$refs.sessionEditGrid.Reload();
              this.$refs.editModal.Close();
          }
        }
      },
      getEconomyBases() {
        app.api.Get("economy_base")
          .then(Response => this.economyBases = Response );
      }
    }
};
</script>
